Module utils

Module utils 

Structs

ClassifyResults
SingletonKmers

Constants

BINSIZE
Discrete bin size to contract regions
CHAIN_DISTANCE
Chain distance to merge regions
DEFAULT_FLANK_SIZE
Flank size to extract from the region
MAX_DE
Maximum divergence

Functions

index_bam
Build BAM index if needed
need_update
Check if any file in the list a is newer than any file in the list b
prefix
Get basename
prefix_until_dot
Get basename and up to the first dot in the path
sh
Run shell command