Structs
Constants
- BINSIZE
- Discrete bin size to contract regions
- CHAIN_
DISTANCE - Chain distance to merge regions
- DEFAULT_
FLANK_ SIZE - Flank size to extract from the region
- MAX_DE
- Maximum divergence
Functions
- index_
bam - Build BAM index if needed
- need_
update - Check if any file in the list
ais newer than any file in the listb - prefix
- Get basename
- prefix_
until_ dot - Get basename and up to the first dot in the path
- sh
- Run shell command